from __future__ import absolute_import
from webassets.filter import Filter


__all__ = ('Jinja2',)


class Jinja2(Filter):
    """Process a file through the Jinja2 templating engine.

    Requires the ``jinja2`` package (https://github.com/mitsuhiko/jinja2).
    """

    name = 'jinja2'
    options = {
        'context': 'JINJA2_CONTEXT',
    }

    def setup(self):
        try:
            import jinja2
        except ImportError:
            raise EnvironmentError('The "jinja2" package is not installed.')
        else:
            self.jinja2 = jinja2
        super(Jinja2, self).setup()

    def output(self, _in, out, **kw):
        out.write(self.jinja2.Template(_in.read()).render(self.context or {}))



from __future__ import absolute_import

import gzip
from webassets.filter import Filter


__all__ = ('GZip',)


class GZip(Filter):
    """Applies gzip compression to the content given.

    This can be used if you are unable to let the webserver do the
    compression  on the fly, or just want to do precaching for additional
    performance.

    Note that you will still need to configure your webserver to send
    the files out marked as gzipped.
    """

    name = 'gzip'

    def output(self, _in, out, **kw):
        zfile = gzip.GzipFile(mode='wb', compresslevel=6, fileobj=out)
        try:
            zfile.write(_in.read())
        finally:
            zfile.close()



# Import assets configuration
from assets import bundle

print 'Content-Type: text/html'
print ''
print '''
<html>
   <head>'''
for url in bundle.urls():
    print '<link rel="stylesheet" type="text/css" href="%s" />' % url
print '''
   </head>
   <body>
      Hello World!
   </body>
</html>
'''

